bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 21. Aventiure
___________________________________________________
| ### Di boten lazen riten wir svln iv tvn bechant ### wi div chvneginne fvere dvrch div lant ### oder wa von ir schiden Giselher vnd Gernot ### si heten ir gedienet als in ir triwe daz gebot [354a] ### Vnz an di Tvnowe ce Vergen si do ritten ### si begonden vrlovbes di <chvenegin> bitten ### wan si wider wolden riten an den Rin ### done moht ez ane weinen von gvten frivnden niht gesin
###### 1289 | ### Giselher der snelle sprach cer swester sin ### swenne daz dv vrowe bedvrfen wellest min ### ob dir iht gewerre daz tv dv mir bechant ### so rit ich dir ce dineste in daz Eceln lant
| ### Di ir mage waren chvstes an den mvnt ### vil minnecliche sheiden sach man an der stvnt ### von Rvedgeres des margraven man ### do fvrt div chvneginne vil manige meit wolgetan
###### 1291 | ### Hvndert vnd viere di trvgen richiv cleit ### von gemalet richen pfellel vil der schilde breit ### fvrt man bi den vrowen nahen vf den wegen ### do cherte von ir dannen vil manich herlicher degen
###### 1292 | ### Si zogeten dannen balde nider dvrch Peyerlant ### do sagte man div mære da wæren fvr gerant ### vil vnchvnder geste da noch ein chloster stat ### vnt da daz <Ÿn> mit flvhe in di Tvonowe gat
| ### In der stat ce Pazzowe saz ein besschof ### di berge wrden lære vnt ovch des fvrsten hoff ### si ilten gegen den vff in Beyerlant ### da der bisschoff Pilgrin di schoenen Criemhilden vant
###### 1294 | ### Den recken von dem lande was do niht ce leit ### do si ir volgen sahen so manige schone meit ### da trvte man mit ovgen der edeln ritter chint ### gvte herberge gap man den gesten sint
###### 1295 | ### Der bisschoff mit siner nifteln ce Pazzowe reit ### do daz den bvrgæren von der stat wart geseit ### daz dar choeme Criemhilt des fvrsten swester chint ### div wart wol enpfangen von den chovflivten sint
| ### Daz si beliben solden der bisschof hetes wan ### do sprach der herre Ecchewart ez ist vngetan ### wir mvzen varn nider in Rvdgeres lant ### vns wartet vil der degene [354b] wan iz ist in allen wol bechant
###### 1297 | ### Div mære nv wol wesse div schone Gotelint ### si bereite sich mit vlize vnde ir vil edel chint ### ir het enboten Rvedger daz in daz dvehte gvt ### daz si der chveneginne da mite troste den mvt
###### 1298 | ### daz si ir rite engenge mit den sinen man ### vf zv der Ense do daz wart getan ### do sah man allenthalben di wege vnmvzech sten ### si begonden gegn den gesten beidiv riten vnd gen
| ### Nv was div chvneginne ze Everdingen chomen ### genvge vz Peyerlande <solden> si han genomen ### den rovb vf der strazzen nach ir gewonheit ### so heten si den gesten da getan vil lihte leit
###### 1300 | ### Daz was wol vnderstanden von dem margraven her ### er fvrte tvsent ritter vnt dannoch mer ### do was ovch chomn Gotelint Rvedegeres wip ### mit ir chom herliche vil maniges edeln rechen wip
###### 1301 | ### Do si vber di Trwoen chomen bi (ê)nse vf daz velt ### do sah man vf gespannen hvetten vnt gecelt ### da di geste solden di nahtselde han ### div choste was den gesten da von Rvedger getan
| ### Gotelint div schone di herberge lie ### hinder ir beliben vf den wegen gie ### mit chlingenden zovmen manich pfært wolgetan ### der antpfanch wart vil schone liep was iz Rvedger getan
###### 1303 | ### Di in ce beden siten chomen vf den wegen ### di riten lobeliche der was vil manich degen ### si pflagen ritterschepfte daz sach vil manich meit ### ovch was der ritter dienest niht der kvneginne leit
###### 1304 | ### Do zv den gesten chomen di Rvedgeres man ### vil der trvonzzvne sach man ze berge gan ### von der recken hende mit ritterlichen siten ### da wart wol ce prise vor den vrowen do geritten [355a]
###### 1305 | ### <daz> liezen si beliben do grvzte manich man ### vil gvtliche ein ander do fvrten si von dan ### di schonen Gotelinden da si Criemhilde sach ### di vrowen dienen chvnden di heten chleinen gemach
###### 1306 | ### Der voget von Bechelaren ce sinem wibe reit ### der edeln margravinne was daz <niht> ce leit ### daz er so wol gesvnder was von Rine chomen ### ir was ein teil ir swære mit grozen vrevden benomen
###### 1307 | ### Do sin het enpfangen er hiez si vf daz gras ### erbeizen mit den vrowen swaz ir da mit ir was ### da wart vil vnmvzech manich edel man ### da wart vrowen dienest mit grozem vlize getan
| ### Do sach div vrowe Criemhilt di margravinne sten ### mit ir gesinde sine lie niht naher gen ### daz pferht mit dem zovme zvchen si began ### vnd bat sich snellechlichen heben von dem satel dan
###### 1309 | ### Den bisschoff sach man wisen siner swester chint ### in vnd Eckewarten zv Gotelinde sint ### da wart vil michel wichen an der selben stvnt ### do chvste div ellende an der Gotelinden mvnt
###### 1310 | ### Do sprach <vil> minnechlichen daz Rvedgeres wip ### nv wol mich liebiv vrowe daz ich iweren schonen lip ### han in disen <landen> mit minen ovgen gesehen ### mir enchvnde an disen ziten nimmer lieber geschehen
| ### Nv lon iv got sprach Criemhilt vil edeliv Gotelint ### sol ich gesvnt beliben vnd Botelvnges chint ### ez mag iv <chomen> ze liebe daz ir mich <habt> gesehen ### in beiden was vnchvnde daz sider mvse geschen
###### 1312 | ### Mit zvehten zv zein ander gie vil manich meit ### do waren in di recken mit dieneste vil bereit ### si sazen nach dem grvze nider vff den chle ### si gewnnen maniger chvende di in vil vremede waren ê
###### 1313 | ### Man hiez den vrowen schenchen ez was wol mitter tach ### daz edel ingesinde da niht lenger lach ### si riten da si fvnden manige hvetten breit ### da was den edeln gesten vil michel dienest bereit
| ### Di naht si heten rwe vnz an den morgen vrv ### di von Bechelaren berei [355b] ten sich dar zv ### wi si behalten solden vil manigen vremden gast ### wol het gehandelt Rvedeger daz in da wenich iht gebrast
###### 1315 | ### Div venster an den mvren sah man offen stan ### div bvrch ce Bechelaren div was vf getan ### do riten dar in di geste di man vil gerne sach ### den hiez der wirt vil edele schaffen gvten gemach
###### 1316 | ### Div Rvedgeres thohter mit ir gesinde gie ### da si di chveneginne vil minnechlich enpfie ### da was ovch ir mvter des margaven wip ### mit liebe wart gegrvezet vil maniger ivnchvrowen lip
| ### Si fiengen sich behanden vnt giengen dan ### in einen palas witen der was vil wol getan ### da div Tvonowe vnder hin vloz ### si sahen gegen dem lvfte vnde heten chvercewile groz
###### 1318 | ### Wes si da mere pflægen desen chan ich niht gesagen ### daz in so vbele zogete <daz> horte man do chlagen ### di Criemhilde recken wan iz was in leit ### hey waz do gvter degene mit ir von Bechelaren reit
###### 1319 | ### Vil minnechlichen dienest Rvdger in bot ### do gap div chvneginne zwelf armbovge rot ### der Gotelinde tohter vnt also gvt gewant ### daz si niht bezzers brahte in diz lant
| ### Swi ir gnomen wære der Nibelvnge golt ### alle di si gesahen di machete si ir holt ### noch mit dem chleinem gvte da si da mohte han ### des wirtes ingesinde dem wart groziv gabe getan
###### 1321 | ### Da wider bot do ere div vrowe Gotelint ### den gesten von dem Rine so gvetliche sint ### daz man der vremden harte wenich vant ### si trvegen ir gesteine oder ir vil herlich gewant
###### 1322 | ### Do si enbizzen waren vnt daz si solden dan ### von der hvsvrowen wart geboten an ### getriwerlicher dienest daz Eceln wip ### da wart vil getrivtet der ivnchvrowen lip
| ### Si sprach cer kveneginne swenne ivch nv dvnchet gvt ### ich weiz wol daz iz gerne min lieber vater tvt ### daz er mich zv ziv sendet in der Hivnen lant ### daz si ir getriwe wære vil wol daz Criemhilt ervant
###### 1324 | ### Div ross bereitet waren vnt fver Bechelaren chomen ### do hete div edel chvne [356a] ginne vrlovp nv genomen ### von Rvdgeres wibe vnd der tohter sin ### do schied ovch sich mit grvze vil manich schonez magedin
###### 1325 | ### Ein ander si vil selten gesahen nach den tagen ### vzzer Medeliche vf handen wart getragen ### vil manich goltvaz riche dar inne braht man win ### des gesten zv der straze si mvsen willechomen sin
| ### Ein wirt was da gesezzen Astolt was der genant ### der wiste si di straze in daz Osterlant ### gegen Mvtaren di Tvonowe nider ### da wart vil wol gedienet der kveneginne sider
###### 1327 | ### Der bisschoff minnechliche von siner niftel schiet ### daz si sich wol gehabte wi vast er ir daz reit ### vnt daz si ir ere chovffte als Helche het getan ### hey waz si grozer eren sit da cen Hivnen gewan
###### 1328 | ### Zv der Treisem brathe man di geste dan ### ir pflagen vlizechliche di Rvedegeres man ### vnze daz Hivnen ritten veber lant ### do wart der kvneginne vil michel ere bechant
###### 1329 | ### Bi der Treisem hete der chvnich von Hivnen lant ### eine bvrch vil riche div was vil wol bechant ### geheizen Zeyzenmvre vrov Helche saz da ê ### vnt pflach so grozer tvgende daz wærlich nimmer mer erge
| ### Ezen tæte danne Criemhilt div also chvnde geben ### si mohte nach ir leide daz liep vil wol geleben ### daz ir ovch iahen ere di Eceln man ### der si sit grozen vollen bi den helden gewan
###### 1331 | ### Div Eceln herschaft was so wit erchant ### daz man zallen ziten in sinem hove vant ### di chvnesten recken von den ie wart vernomen ### vnder Cristen vnd vnder heiden di waren mit im alle chomen
###### 1332 | ### Bi im was zallen ziten daz wætlich mer erge ### cristenlicher orden vnt ovch der heiden ê ### in swi getanem leben sich ietslicher trvch ### daz schvf des chveniges milte daz man in allen gap genvch

<<< Übersicht <<< vorige Seite nächste Seite >>>